#!/bin/sh
#DEBUG=TRUE

################################################################################
#
# Header
#
# Licensed Materials - Property of IBM Corp.
# (C) Copyright IBM Corp. 2004
# 
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

SCRIPT_VER=01.07
SCRIPT_DATE=06/30/2006
SCRIPT_SCCS=

################################################################################
#
# History
#
# DATE        Ver    Auth         Abstract
# ----------  -----  -----------  ----------------------------------
# 11/15/2004  00.01  brookh       initial design 
# 11/18/2004  01.00  brookh       add "-v" option
# 11/26/2004  01.01  brookh       Check server status before stop/start
# 11/26/2004  01.02  brookh       .pid file is not reliable immediately after 
#                                  start/stop, so only check before first start
# 06/22/2005  01.03  dukepham     Add copying IDSWebApp.war to installableApps/SHOMEPath
#                                 and change the way this script to be executed
#                                 at <LDAPHome>/idstools/
# 05/15/2006  01.05  Amit Kumar   Support for -h, -f, -a, -e and -r options 
#                                 in the deployment script
# 05/25/2006  01.06  Aalhad Saraf Remove redundant options. Integrate SunOS code.
# 05/25/2006  01.07  Amit Kumar   script should run from idstools folder

################################################################################
################################################################################
#
#Usage: ./deploy_IDSWebApp.sh [-v] [-h] [-w IDSWebApp.war file] 
#                             [-a Application Name [-u]]
#                             [-p location of app server] [-r profile]
#
# Deploys IDSWebApp.war to WAS, retaining the configuration settings of  the 
# currently deployed IDSWebApp, if any.
#
#NOTE:   deploy_IDSWebApp.bat must be present in /TDS installpath/idstools folder.
#        
#
#{-h     Display Usage. }
#
#{-v     Display the version and date strings for the deploy_IDSWebApp
#        script and the application war file.}
#
#{-a     Application Name. Defaults to IDSWebApp.war if not specified. }
#
#{-u     Uninstall a previously existing application.
#        -a option should be used to specify the application to uninstall
#        If not specified default application IDSWebApp.war would be 
#        un-deployed.}
#
# The following options are necessary for all operations associated with 
# non-embedded WAS deployments and optionally may also be used for embedded 
# WAS.
#
#{-w     The fully qualified path of the IDSWebApp.war file to deploy.  }
#
#{-p     Location of WebSphere Application Server where the application is
#        to be deployed. }
#
#{-r     Profile name associated with the application. Default assumed if not
#        specified is - 'profile1'. This option will be ignored for embedded WAS 
#        deployments.}
#
#
################################################################################
################################################################################


DEBUG_FLAG="FALSE"
MAIN_PLATFORM=`eval 'uname'`
IDSWebAppWarFileName="IDSWebApp.war"
EXETIMESTAMP=`date +"%m-%d-%y_%H-%M-%S"`
DefaultWASHOMEPath=`eval 'dirname $0'`/../appsrv/
WAS_SERVER=server1
WASHOMEPath=
PATCH_SCRIPT=
WAS_TEMP=
APP_ROOT=
IDSWebApp_Name=
IDSToolsPath=
IDSWebApp=
NEW_IDSWebApp=
OPTION_V=FALSE
IDSWebAppInfo=WEB-INF/classes/IDSConfig/IDSWebAppInfo/IDSWebAppInfo.xml
CONFIG_FILES="\
    WEB-INF/classes/security/console_passwd \
    WEB-INF/classes/IDSConfig/IDSServersConfig/IDSServersInfo.xml \
    WEB-INF/classes/IDSConfig/IDSAppReg/IDSAppReg.xml \
    WEB-INF/classes/IDSConfig/IDSSessionConfig/IDSSessionMgmt.xml \
    "
NewIDSWebAppWarVer=
DeployedIDSWebAppWarVer=
QualifiedPath=
WAS_NODE=DefaultNode
UNINSTALL_TEMP="${WAS_HOME}/temp/uninstall_IDSWebApp.tmp"
BOBCAT_SERV=FALSE
UNINSTALL_ONLY=FALSE


################################################################################
#
# Set QualifiedPath of $1, or return error and clear QualifiedPath
#
QualifyPath()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    if [ $1 ]; then
        QualifiedPath=
        save_PWD=`pwd`
        cd `dirname ${1}` || return $?
        QualifiedPath=`pwd`/`basename ${1}`
        cd ${save_PWD}
    else                    ## $1 is null
        QualifiedPath=`pwd`
    fi
}

################################################################################
#
# Delete ${WAS_HOME}/temp/uninstall_IDSWebApp.tmp directory
#  Used during uninstall_only
#
uninstall_DeleteTempDirectory()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi
    if [ -d ${UNINSTALL_TEMP} ]; then
        rm -rf ${UNINSTALL_TEMP}
    fi
}


################################################################################
#
# Create empty ${WAS_HOME}/temp/uninstall_IDSWebApp.tmp directory
# Used during uninstall_only
#
uninstall_CreateTempDirectory()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi
    uninstall_DeleteTempDirectory || return $?
    mkdir -p ${UNINSTALL_TEMP} || return $?
}

################################################################################
#
# Backup CONFIG_FILES (if any) from APP_ROOT to UNINSTALL_TEMP
# Used during uninstall_only
#
uninstall_Backup_IDSWebApp_Configuration()
{

    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    #Set up the environment variables
    if [ -d ${APP_ROOT} ]; then
        :
    else
        return 0
    fi
    for filename in ${CONFIG_FILES}; do
        if [ -f ${APP_ROOT}/${filename} ]; then
            EchoCmd mkdir -p ${UNINSTALL_TEMP}/`dirname ${filename}` || return 1
            EchoCmd cp ${APP_ROOT}/${filename} ${UNINSTALL_TEMP}/${filename} || return 1
        fi
    done
    return 0
}

################################################################################
# This function is used to only uninstall the already installed IDSWebApp.war 
# application
#

uninstall_only () {

    echo ""
    echo "You have chosen to undeploy ${IDSWebApp_Name}"
    echo ""
    echo "The configuration files for the current application will be stored in ${WAS_HOME}/temp/uninstall_IDSWebApp.tmp"

    if [ -z "${IDSWebApp_Name}" ]; then
        IDSWebApp_Name="IDSWebApp.war"
        echo "No Application name supplied. The default application IDSWebApp.war will be undeployed"
    else
        echo "An Application name has been supplied. The application ${IDSWebApp_Name} will be undeployed"
    fi

    uninstall_CreateTempDirectory || return $?
    uninstall_Backup_IDSWebApp_Configuration || return $?

    if [ ${BOBCAT_SERV} = FALSE ]; then
        if [ ! -f ${WAS_HOME}/profiles/${PROFILE_NAME}/logs/${WAS_SERVER}/${WAS_SERVER}.pid ]; then
            Start_WAS || return $?
        fi
    else           
        if [ ! -f ${WAS_HOME}/logs/${WAS_SERVER}/${WAS_SERVER}.pid ]; then
            Start_WAS || return $?
        fi
    fi

    Uninstall_IDSWebApp
    exit 0;

}

################################################################################
# This function is used to print the help for deploy_IDSWebApp.sh
#


printusage () {

echo "Usage: ./deploy_IDSWebApp.sh [-v] [-h] [-w IDSWebApp.war file] 
                                   [-a Application Name [-u]] 
                                   [-p location of app server] [-r profile]

Deploys IDSWebApp.war to WAS, retaining the configuration settings of the 
currently deployed IDSWebApp, if any.

NOTE:   deploy_IDSWebApp.sh must be present in /TDS installpath/idstools/ folder.
        

{-h     Display Usage. }

{-v     Display the version and date strings for the deploy_IDSWebApp
        script and the application war file.}

{-a     Application Name. Defaults to IDSWebApp.war if not specified. }

{-u     Uninstall a previously existing application.
        -a option should be used to specify the application to uninstall
        If not specified default application IDSWebApp.war would be un-deployed.}

The following options are necessary for all operations associated with 
non-embedded WAS deployments and optionally may also be used for embedded WAS.

{-w     The fully qualified path of the IDSWebApp.war file to deploy.  }

{-p     Location of WebSphere Application Server where the application is
        to be deployed. }

{-r     Profile name associated with the application. Default assumed if not
        specified is - 'profile1'. This option will be ignored for embedded WAS 
        deployments.}
"

exit 0

}

################################################################################
#
# Print localized "File not found" error and return failure RC
#
AssertFileExists()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    if [ ! -f $1 ]; then
        ls $1 >/dev/null
    fi
}

################################################################################
#
# Echo cmd and then call it
#
EchoCmd()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    echo ""
    echo "$*"
    eval "$*"
}


################################################################################
#
# Initialize all needed variables
#
InitGlobalVariables()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    QualifyPath $1 || return $?
    IDSToolsPath=`dirname ${QualifiedPath}`
    PATCH_SCRIPT=${QualifiedPath}

    if [ ${WASHOMEPath} ]; then
        :
    else
        QualifyPath ${DefaultWASHOMEPath} || return $?
        WASHOMEPath=${QualifiedPath}
    fi


    if [ -z "${IDSWebApp_Name}" ]; then
        IDSWebApp_Name="IDSWebApp.war"
    fi

    ## Execution of setupCmdLine.sh will set all needed environment variables
    ## such as: ${WAS_HOME} and ${JAVA_HOME} etc.
    cd "${WASHOMEPath}/bin/"

    AssertFileExists "${WASHOMEPath}/bin/setupCmdLine.sh" || return $?
    . "${WASHOMEPath}/bin/setupCmdLine.sh" || return $?
    cd ${IDSToolsPath}

    AssertFileExists "${WASHOMEPath}/bin/wsadmin.sh" || return $?

    UNINSTALL_TEMP="${WAS_HOME}/temp/uninstall_IDSWebApp.tmp"

    if [ ! -f "${WASHOMEPath}/bin/wasprofile.sh" ]; then
        BOBCAT_SERV=TRUE
    fi

    WAS_TEMP="${WAS_HOME}/temp/deploy_IDSWebApp.tmp"

    APP_ROOT="${WAS_HOME}/installedApps/${WAS_NODE}/${IDSWebApp_Name}.ear/IDSWebApp.war"

    if [ ${BOBCAT_SERV} = FALSE ]; then
        APP_ROOT=${WAS_HOME}/profiles/${PROFILE_NAME}/installedApps/DefaultNode/${IDSWebApp_Name}.ear/IDSWebApp.war
    fi

    if [ ${PROFILE_NAME} ]; then
        :
    else
        PROFILE_NAME=profile1
    fi

    if [ ${IDSWebApp} ]; then
        NEW_IDSWebApp=${IDSWebApp}
    else
        if [ "${MAIN_PLATFORM}" = "AIX" ]; then
            AssertFileExists ${IDSToolsPath}/${IDSWebAppWarFileName?} 
            if [ $? -eq 0 ]; then
                QualifyPath ${IDSToolsPath}/${IDSWebAppWarFileName?}
            else
                AssertFileExists ${IDSToolsPath}/nossl/${IDSWebAppWarFileName?} || return $?
                QualifyPath ${IDSToolsPath}/nossl/${IDSWebAppWarFileName?}
            fi
        else
            AssertFileExists ${IDSToolsPath}/${IDSWebAppWarFileName?} || return $?
            QualifyPath ${IDSToolsPath}/${IDSWebAppWarFileName?}
        fi
        NEW_IDSWebApp=${QualifiedPath}
    fi
}

################################################################################
#
# Delete ${WAS_HOME}/temp/IDSWebApp.tmp directory
#
DeleteTempDirectory()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    if [ -d ${WAS_TEMP} ]; then
        rm -rf ${WAS_TEMP}
    fi
}

################################################################################
#
# Create empty ${WAS_HOME}/temp/IDSWebApp.tmp directory
#
CreateTempDirectory()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    DeleteTempDirectory || return $?
    mkdir -p ${WAS_TEMP} || return $?
}

################################################################################
#
# Backup CONFIG_FILES (if any) from APP_ROOT to WAS_TEMP
#
Backup_IDSWebApp_Configuration()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    ## Set up the environment variables

    if [ ! -d ${APP_ROOT} ]; then
        return 0
    fi

    for filename in ${CONFIG_FILES}; do
        if [ -f ${APP_ROOT}/${filename} ]; then
            EchoCmd mkdir -p ${WAS_TEMP}/`dirname ${filename}` || return 1
            EchoCmd cp ${APP_ROOT}/${filename} ${WAS_TEMP}/${filename} || return 1
        fi
    done

    return 0
}

################################################################################
#
# Restore CONFIG_FILES (if any) from WAS_TEMP to APP_ROOT
#
Restore_IDSWebApp_Configuration()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    for filename in ${CONFIG_FILES}; do
        if [ -f ${WAS_TEMP}/${filename} ]; then
            EchoCmd cp ${WAS_TEMP}/${filename} ${APP_ROOT}/${filename} || return 1
        fi
    done

    return 0
}


################################################################################
#
# Start WAS server1
#
Start_WAS()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    if [ ${BOBCAT_SERV} = FALSE ]; then
        EchoCmd "${WAS_HOME}/profiles/${PROFILE_NAME}/bin/startServer.sh" ${WAS_SERVER} || return $?
    else
        EchoCmd "${WAS_HOME}/bin/startServer.sh" ${WAS_SERVER} || return $?
    fi
}

################################################################################
#
# Stop WAS server1
#
Stop_WAS()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi
    if [ ${BOBCAT_SERV} = FALSE ]; then
        EchoCmd "${WAS_HOME}/profiles/${PROFILE_NAME}/bin/stopServer.sh" ${WAS_SERVER} || return $?
    else
        EchoCmd "${WAS_HOME}/bin/stopServer.sh" ${WAS_SERVER} || return $?
    fi
}

################################################################################
#
# Restart WAS server1
#
Restart_WAS()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    Stop_WAS
    Start_WAS || return $?
}

################################################################################
#
# Un-deploy existing IDSWebApp.war (if found)...
#
Uninstall_IDSWebApp()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    if [ -d ${APP_ROOT} ]; then
        if [ ${BOBCAT_SERV} = FALSE ]; then
            EchoCmd ${WAS_HOME}/bin/wsadmin.sh '-conntype NONE -profileName ${PROFILE_NAME} -c "\$AdminApp uninstall ${IDSWebApp_Name}"' || return $?
        else
            EchoCmd ${WAS_HOME}/bin/wsadmin.sh '-conntype NONE -c "\$AdminApp uninstall ${IDSWebApp_Name}"' || return $?
        fi
    fi 
    return 0
}

################################################################################
#
# Deploy new IDSWebApp.war...
#
Install_IDSWebApp()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    if [ ${BOBCAT_SERV} = FALSE ]; then
	cd "${WASHOMEPath}/bin/"
        
	EchoCmd ${WAS_HOME}/bin/wasprofile.sh '-create -profileName ${PROFILE_NAME} -profilePath "${WAS_HOME}/profiles/${PROFILE_NAME}" -templatePath "${WAS_HOME}/profileTemplates/default" -nodeName DefaultNode -hostName localhost -cellName DefaultNode -isDefault'
	
        EchoCmd ${WAS_HOME}/bin/wsadmin.sh '-conntype NONE -c "\$AdminApp install {'${WAS_HOME}/installableApps/IDSWebApp.war'} {-configroot \"${WAS_HOME}/config\" -node DefaultNode -usedefaultbindings -nodeployejb -appname ${IDSWebApp_Name} -contextroot \"IDSWebApp\"}"'
	
	cd ${IDSToolsPath}
    else
        EchoCmd ${WAS_HOME}/bin/wsadmin.sh '-conntype NONE -c "\$AdminApp install {'${NEW_IDSWebApp}'} {-configroot \"$CONFIG_ROOT\" -node \"$WAS_NODE\" -usedefaultbindings -nodeployejb -appname ${IDSWebApp_Name} -contextroot \"IDSWebApp\"}"'      
    fi

    return $?
}

################################################################################
#
# Display app-version and build-date of IDSWebAppInfo.xml file
#   or localized 'not found' message
#
ShowIDSWebAppInfo()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    if [ -f $1 ]; then
        egrep '(app-version|build-date)' $1
    else
        ls $1 >/dev/null
    fi
}

################################################################################
#
# get the major version of the new war file to:
#  ${NewIDSWebAppWarMajorVer}
#
GetVersionInfo_NewIDSWebApp()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    if [ -f ${1} ]; then
        save_PWD=`pwd`
        cd ${WAS_TEMP}
        ${JAVA_HOME}/bin/jar -xf ${1} ${IDSWebAppInfo}
        cd ${save_PWD}
    else
        return 1
    fi

    ## Get the major version of the new war file
    #AssertFileExists ${WAS_TEMP}/${IDSWebAppInfo} || return $?
    temp_ver1=`egrep '(app-version)' ${WAS_TEMP}/${IDSWebAppInfo}`
    temp_ver2=`echo ${temp_ver1} | awk -F\> '{print $2}'`
    temp_ver3=`echo ${temp_ver2} | awk -F\< '{print $1}'`
    NewIDSWebAppWarMajorVer=`echo ${temp_ver3} | awk -F\. '{print $1}'` 
}

################################################################################
#
# get the major version of deployed war in WAS:
#  ${DeployedIDSWebAppWarVer}
#
GetVersionInfo_DeployedIDSWebApp()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    if [ -f ${1} ]; then
        temp_ver1=`egrep '(app-version)' ${1}`
        temp_ver2=`echo ${temp_ver1} | awk -F\> '{print $2}'`
        temp_ver3=`echo ${temp_ver2} | awk -F\< '{print $1}'`
        DeployedIDSWebAppWarVer=`echo ${temp_ver3} | awk -F\. '{print $1}'`
    else
        return 0
    fi
}

################################################################################
#
# "-v"
# ShowVersionInfo() is made to act as a standalone entity.It would 
# initialize its own varibles needed to determine the version and 
# exit.
#
ShowVersionInfo()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    ## Show script version
    echo ""
    echo "${PATCH_SCRIPT}:"
    echo "    SCRIPT_VER:  ${SCRIPT_VER}"
    echo "    SCRIPT_DATE: ${SCRIPT_DATE}"


    QualifyPath $1 || return $?
    IDSToolsPath=`dirname ${QualifiedPath}`
    PATCH_SCRIPT=${QualifiedPath}

    if [ ${WASHOMEPath} ]; then
        :
    else
        QualifyPath ${DefaultWASHOMEPath} || return $?
        WASHOMEPath=${QualifiedPath}
    fi


    if [ -z "${IDSWebApp_Name}" ]; then
        IDSWebApp_Name="IDSWebApp.war"
    fi

    ## Execution of setupCmdLine.sh will set all needed environment variables
    ## such as: ${WAS_HOME} and ${JAVA_HOME} etc.

    AssertFileExists "${WASHOMEPath}/bin/setupCmdLine.sh" || return $?
    . "${WASHOMEPath}/bin/setupCmdLine.sh" || return $?

    ## Show version of new IDSWebApp
    echo ""
    echo "${NEW_IDSWebApp}:"

    if [ ! -f "${WASHOMEPath}/bin/wasprofile.sh" ]; then       
        BOBCAT_SERV=TRUE
    fi

    APP_ROOT="${WAS_HOME}/installedApps/${WAS_NODE}/${IDSWebApp_Name}.ear/IDSWebApp.war"
    if [ ${BOBCAT_SERV} = FALSE ]; then
        APP_ROOT=${WAS_HOME}/profiles/${PROFILE_NAME}/installedApps/DefaultNode/${IDSWebApp_Name}.ear/IDSWebApp.war
    fi

    ShowIDSWebAppInfo ${APP_ROOT}/${IDSWebAppInfo}

    exit 0
}

################################################################################
#
# Copy the new war to the <WAS install path>/installableApps/ after
#  sucessfully deployed the war file.
#
Copy_NewIDSWebApp_To_InstallableApps()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    AssertFileExists ${WAS_HOME}/installableApps/IDSWebApp.war

    if [ $? -eq 0 ]; then
        ## Backup target file before copying if it exists
        mv ${WAS_HOME}/installableApps/IDSWebApp.war \
        ${WAS_HOME}/installableApps/IDSWebApp.war_bkup_${EXETIMESTAMP} || return $?
    fi

    ## Copy to override target
    cp -Rp ${NEW_IDSWebApp} ${WAS_HOME}/installableApps/ || return $?
}

################################################################################
#
# Only allow to deploy war file with exact name: "IDSWebApp.war"
#
Verify_IDSWebApp_Filename()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    ## Only set -x when about to quit
    [ "${1?}" != "${IDSWebAppWarFileName?}" ] && set -x
    [ "${1?}" != "${IDSWebAppWarFileName?}" ] && return 1
    return 0
}

################################################################################
#
# Verify war file version and only allow equal of newer version to be
#  deployed into already deployed WAS installation.
#
Verify_IDSWebApp_Version()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    ## Check the war file version, and DO NOT allow back level war file
    ## to be deployed to a newer version of deployed WAS.
    if [ ${DeployedIDSWebAppWarVer} ]; then
        [ ${NewIDSWebAppWarMajorVer} -lt ${DeployedIDSWebAppWarVer} ] && set -x
        if [ ${NewIDSWebAppWarMajorVer} -lt ${DeployedIDSWebAppWarVer} ]; then
            ## Show version of new IDSWebApp
            echo ""
            echo "${NEW_IDSWebApp}:"
            ShowIDSWebAppInfo ${WAS_TEMP}/${IDSWebAppInfo}
            ## Show version of deployed IDSWebApp
            echo ""
            echo "${APP_ROOT}/${IDSWebAppInfo}:"
            ShowIDSWebAppInfo ${APP_ROOT}/${IDSWebAppInfo}
            return 1         
        fi
    fi

    return 0
}

################################################################################
#
# main
#
main()
{
    if [ ${DEBUG_FLAG} = TRUE ]; then
        set -x
    fi

    if [ ${OPTION_V} = TRUE ]; then
        ShowVersionInfo
    fi

    InitGlobalVariables $1 || return $?
    CreateTempDirectory || return $?

    GetVersionInfo_NewIDSWebApp ${NEW_IDSWebApp} || return $?
    GetVersionInfo_DeployedIDSWebApp ${APP_ROOT}/${IDSWebAppInfo}

    if [ ${UNINSTALL_ONLY} = TRUE ];then
        uninstall_only
        exit 0;
    fi

    if [ ${OPTION_V} = FALSE ]; then
        Verify_IDSWebApp_Version || return $?

        if [ ${BOBCAT_SERV} = FALSE ]; then
            if [ -f ${WAS_HOME}/profiles/${PROFILE_NAME}/logs/${WAS_SERVER}/${WAS_SERVER}.pid ]; then
                Stop_WAS
                if [ $? -ne 0 ]; then
                    Start_WAS || return $?
                    Stop_WAS || return $?
                fi
            fi
        else
            if [ -f ${WAS_HOME}/logs/${WAS_SERVER}/${WAS_SERVER}.pid ]; then
                Stop_WAS
                if [ $? -ne 0 ]; then
                    Start_WAS || return $?
                    Stop_WAS || return $?
                fi
            fi
        fi 

        Backup_IDSWebApp_Configuration || return $?
        Uninstall_IDSWebApp || return $?
        Install_IDSWebApp || return $?
        Restore_IDSWebApp_Configuration || return $?
        Restart_WAS || return $?
        Copy_NewIDSWebApp_To_InstallableApps || return $?

        if [ ${BOBCAT_SERV} = FALSE ]; then
            APP_ROOT=${WAS_HOME}/profiles/${PROFILE_NAME}/installedApps/DefaultNode/${IDSWebApp_Name}.ear/IDSWebApp.war
        fi

        DeleteTempDirectory
        echo ""
        if [ ${BOBCAT_SERV} = TRUE ]; then
		echo "${APP_ROOT}:"
        	ShowIDSWebAppInfo ${APP_ROOT}/${IDSWebAppInfo}
	fi
    fi
}

################################################################################
         ###################### MAIN PROGRAM #########################
################################################################################

if [ ${DEBUG} ]; then
   DEBUG_FLAG=${DEBUG}
fi

while getopts ":vw:p:a:r:uh" opt
do
   case $opt in
   v )
      OPTION_V=TRUE
      ;;
   w )
      AssertFileExists $OPTARG || exit $?
      QualifyPath $OPTARG || exit $?
      IDSWebApp=${QualifiedPath}
      ;;
   p )
      QualifyPath $OPTARG || exit $?
      WASHOMEPath=${QualifiedPath}
      ;;
   a )
      IDSWebApp_Name=$OPTARG
      ;;
   u )
      UNINSTALL_ONLY=TRUE
      ;;
   r )
      PROFILE_NAME=$OPTARG
      ;;
   h )
      printusage
      ;;
   \? )
      printusage
      ;;
   * )
      exit $?
      ;;
   esac
done

main $0

