/*
* COMPONENT_NAME: ldap.include
*
* ABSTRACT: Header file for errors returned from ldap_ssl_client_init,
*           ldap_ssl_environment_init, ldap_ssl_init, ldap_ssl_start as well as
*           extended SSL errors that can be generated by other LDAP APIs.  
*           Extended SSL error are retrieved using the ldap_get_option() API, 
*           using the LDAP_OPT_EXT_ERROR option or ldap_get_exterror.
*
* FUNCTIONS:
*
* ORIGINS: 27
*
* (C) COPYRIGHT International Business Machines Corp. 1997, 2002
* All Rights Reserved
* Licensed Materials - Property of IBM
*
* US Government Users Restricted Rights - Use, duplication or
* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
*/

#ifndef _LDAPSSL_H
#define _LDAPSSL_H

#ifndef __OS400__ 
/*
   Extended return codes from SSL functions may be from the GSKit 6 library. 
   The following section defines all GSKit 6 return codes for completeness, 
   many will never be encountered from LDAP SSL function calls.
*/

/* The following may be returned by any SSL functions: */
#define LDAP_SSL_EXTENDED_OK                         0
#define LDAP_SSL_EXTENDED_OK_STR                       "Success"
#define LDAP_SSL_EXTENDED_INVALID_HANDLE             1          /* except 'open' */
#define LDAP_SSL_EXTENDED_INVALID_HANDLE_STR           "Invalid handle"
#define LDAP_SSL_EXTENDED_API_NOT_AVAILABLE          2
#define LDAP_SSL_EXTENDED_API_NOT_AVAILABLE_STR        "API not available"
#define LDAP_SSL_EXTENDED_INTERNAL_ERROR             3
#define LDAP_SSL_EXTENDED_INTERNAL_ERROR_STR           "Internal error"
#define LDAP_SSL_EXTENDED_INSUFFICIENT_STORAGE       4
#define LDAP_SSL_EXTENDED_INSUFFICIENT_STORAGE_STR     "Insufficient storage"
#define LDAP_SSL_EXTENDED_INVALID_STATE              5          /* except 'open' */
#define LDAP_SSL_EXTENDED_INVALID_STATE_STR            "Invalid state"
#define LDAP_SSL_EXTENDED_KEY_LABEL_NOT_FOUND        6
#define LDAP_SSL_EXTENDED_KEY_LABEL_NOT_FOUND_STR      "Key label not found"
#define LDAP_SSL_EXTENDED_CERTIFICATE_NOT_AVAILABLE  7
#define LDAP_SSL_EXTENDED_CERTIFICATE_NOT_AVAILABLE_STR "Certificate not available"
#define LDAP_SSL_EXTENDED_ERROR_CERT_VALIDATION      8
#define LDAP_SSL_EXTENDED_ERROR_CERT_VALIDATION_STR    "Error validating certificate"
#define LDAP_SSL_EXTENDED_ERROR_CRYPTO               9
#define LDAP_SSL_EXTENDED_ERROR_CRYPTO_STR             "Error encrypting/decrypting"
#define LDAP_SSL_EXTENDED_ERROR_ASN                  10
#define LDAP_SSL_EXTENDED_ERROR_ASN_STR                "ASN encoding error"
#define LDAP_SSL_EXTENDED_ERROR_LDAP                 11
#define LDAP_SSL_EXTENDED_ERROR_LDAP_STR               "LDAP error"
#define LDAP_SSL_EXTENDED_ERROR_UNKNOWN_ERROR        12
#define LDAP_SSL_EXTENDED_ERROR_UNKNOWN_ERROR_STR      "Unknown error"

/* The following may be returned by SSL environment initialization */
#define LDAP_SSL_EXTENDED_OPEN_CIPHER_ERROR         101 /* environment only */
#define LDAP_SSL_EXTENDED_OPEN_CIPHER_ERROR_STR        "Open cipher error"
#define LDAP_SSL_EXTENDED_KEYFILE_IO_ERROR          102 /* environment only */
#define LDAP_SSL_EXTENDED_KEYFILE_IO_ERROR_STR         "Keyfile I/O error"
#define LDAP_SSL_EXTENDED_KEYFILE_INVALID_FORMAT    103 /* environment only */
#define LDAP_SSL_EXTENDED_KEYFILE_INVALID_FORMAT_STR    "Keyfile invalid format"
#define LDAP_SSL_EXTENDED_KEYFILE_DUPLICATE_KEY     104 /* environment only */
#define LDAP_SSL_EXTENDED_KEYFILE_DUPLICATE_KEY_STR     "Keyfile duplicate key"
#define LDAP_SSL_EXTENDED_KEYFILE_DUPLICATE_LABEL   105 /* environment only */
#define LDAP_SSL_EXTENDED_KEYFILE_DUPLICATE_LABEL_STR   "Keyfile duplicate label"
#define LDAP_SSL_EXTENDED_BAD_FORMAT_OR_INVALID_PASSWORD 106 /*environment only*/
#define LDAP_SSL_EXTENDED_BAD_FORMAT_OR_INVALID_PASSWORD_STR   "Bad format or invalid password"
#define LDAP_SSL_EXTENDED_KEYFILE_CERT_EXPIRED      107 /* environment only */
#define LDAP_SSL_EXTENDED_KEYFILE_CERT_EXPIRED_STR      "Keyfile certificate expired"
#define LDAP_SSL_EXTENDED_ERROR_LOAD_LDAP_SSL_EXTENDED_LIB  108 /* environment only */
#define LDAP_SSL_EXTENDED_ERROR_LOAD_LDAP_SSL_EXTENDED_LIB_STR "Error loading LDAP library"
#define LDAP_SSL_EXTENDED_PENDING_CLOSE_ERROR       109
#define LDAP_SSL_EXTENDED_PENDING_CLOSE_ERROR_STR      "Pending close error"
#define LDAP_SSL_EXTENDED_NO_KEYFILE_PASSWORD       201 /* neither password nor stash file */
#define LDAP_SSL_EXTENDED_NO_KEYFILE_PASSWORD_STR       "No password nor stash file"
#define LDAP_SSL_EXTENDED_KEYRING_OPEN_ERROR        202
#define LDAP_SSL_EXTENDED_KEYRING_OPEN_ERROR_STR        "Keyring file open error"
#define LDAP_SSL_EXTENDED_RSA_TEMP_KEY_PAIR         203
#define LDAP_SSL_EXTENDED_RSA_TEMP_KEY_PAIR_STR         "RSA temporary key pair"
#define LDAP_SSL_EXTENDED_ERROR_LDAP_NO_SUCH_OBJECT 204
#define LDAP_SSL_EXTENDED_ERROR_LDAP_NO_SUCH_OBJECT_STR "LDAP no such object"
#define LDAP_SSL_EXTENDED_ERROR_LDAP_INVALID_CREDENTIALS 205
#define LDAP_SSL_EXTENDED_ERROR_LDAP_INVALID_CREDENTIALS_STR "LDAP invalid credentials"
#define LDAP_SSL_EXTENDED_ERROR_BAD_INDEX           206
#define LDAP_SSL_EXTENDED_ERROR_BAD_INDEX_STR            "Bad index"
#define LDAP_SSL_EXTENDED_CLOSE_FAILED              301   /*environment close              */
#define LDAP_SSL_EXTENDED_CLOSE_FAILED_STR               "Close failed"

/* The following may be returned during secure socket initialization  */
#define LDAP_SSL_EXTENDED_ERROR_BAD_DATE                       401
#define LDAP_SSL_EXTENDED_ERROR_BAD_DATE_STR                      "Bad date"
#define LDAP_SSL_EXTENDED_ERROR_NO_CIPHERS                     402
#define LDAP_SSL_EXTENDED_ERROR_NO_CIPHERS_STR                    "No ciphers"
#define LDAP_SSL_EXTENDED_ERROR_NO_CERTIFICATE                 403
#define LDAP_SSL_EXTENDED_ERROR_NO_CERTIFICATE_STR                "No certificate"
#define LDAP_SSL_EXTENDED_ERROR_BAD_CERTIFICATE                404
#define LDAP_SSL_EXTENDED_ERROR_BAD_CERTIFICATE_STR               "Bad certificate"
#define LDAP_SSL_EXTENDED_ERROR_UNSUPPORTED_CERTIFICATE_TYPE   405
#define LDAP_SSL_EXTENDED_ERROR_UNSUPPORTED_CERTIFICATE_TYPE_STR  "Unsupported certificate type"
#define LDAP_SSL_EXTENDED_ERROR_IO                             406
#define LDAP_SSL_EXTENDED_ERROR_IO_STR                            "I/O error"
#define LDAP_SSL_EXTENDED_ERROR_BAD_KEYFILE_LABEL              407
#define LDAP_SSL_EXTENDED_ERROR_BAD_KEYFILE_LABEL_STR             "Bad keyfile label"
#define LDAP_SSL_EXTENDED_ERROR_BAD_KEYFILE_PASSWORD           408
#define LDAP_SSL_EXTENDED_ERROR_BAD_KEYFILE_PASSWORD_STR          "Bad keyfile password"
#define LDAP_SSL_EXTENDED_ERROR_BAD_KEY_LEN_FOR_EXPORT         409
#define LDAP_SSL_EXTENDED_ERROR_BAD_KEY_LEN_FOR_EXPORT_STR        "Bad key length for export"
#define LDAP_SSL_EXTENDED_ERROR_BAD_MESSAGE                    410
#define LDAP_SSL_EXTENDED_ERROR_BAD_MESSAGE_STR                   "Bad message"
#define LDAP_SSL_EXTENDED_ERROR_BAD_MAC                        411
#define LDAP_SSL_EXTENDED_ERROR_BAD_MAC_STR                       "Bad MAC"
#define LDAP_SSL_EXTENDED_ERROR_UNSUPPORTED                    412
#define LDAP_SSL_EXTENDED_ERROR_UNSUPPORTED_STR                   "Unsupported"
#define LDAP_SSL_EXTENDED_ERROR_BAD_CERT_SIG                   413
#define LDAP_SSL_EXTENDED_ERROR_BAD_CERT_SIG_STR                  "Bad certificate signature"
#define LDAP_SSL_EXTENDED_ERROR_BAD_CERT                       414
#define LDAP_SSL_EXTENDED_ERROR_BAD_CERT_STR                      "Bad certificate"
#define LDAP_SSL_EXTENDED_ERROR_BAD_PEER                       415
#define LDAP_SSL_EXTENDED_ERROR_BAD_PEER_STR                      "Bad peer"
#define LDAP_SSL_EXTENDED_ERROR_PERMISSION_DENIED              416
#define LDAP_SSL_EXTENDED_ERROR_PERMISSION_DENIED_STR             "Permission denied"
#define LDAP_SSL_EXTENDED_ERROR_SELF_SIGNED                    417
#define LDAP_SSL_EXTENDED_ERROR_SELF_SIGNED_STR                   "Self-signed error"
#define LDAP_SSL_EXTENDED_ERROR_NO_READ_FUNCTION               418
#define LDAP_SSL_EXTENDED_ERROR_NO_READ_FUNCTION_STR              "No read function"
#define LDAP_SSL_EXTENDED_ERROR_NO_WRITE_FUNCTION              419
#define LDAP_SSL_EXTENDED_ERROR_NO_WRITE_FUNCTION_STR             "No write function"
#define LDAP_SSL_EXTENDED_ERROR_SOCKET_CLOSED                  420
#define LDAP_SSL_EXTENDED_ERROR_SOCKET_CLOSED_STR                 "Socket closed"
#define LDAP_SSL_EXTENDED_ERROR_BAD_V2_CIPHER                  421
#define LDAP_SSL_EXTENDED_ERROR_BAD_V2_CIPHER_STR                 "Bad V2 cipher"
#define LDAP_SSL_EXTENDED_ERROR_BAD_V3_CIPHER                  422
#define LDAP_SSL_EXTENDED_ERROR_BAD_V3_CIPHER_STR                 "Bad V3 cipher"
#define LDAP_SSL_EXTENDED_ERROR_BAD_SEC_TYPE                   423
#define LDAP_SSL_EXTENDED_ERROR_BAD_SEC_TYPE_STR                  "Bad security type"
#define LDAP_SSL_EXTENDED_ERROR_BAD_SEC_TYPE_COMBINATION       424
#define LDAP_SSL_EXTENDED_ERROR_BAD_SEC_TYPE_COMBINATION_STR      "Bad security type combination"
#define LDAP_SSL_EXTENDED_ERROR_HANDLE_CREATION_FAILED         425
#define LDAP_SSL_EXTENDED_ERROR_HANDLE_CREATION_FAILED_STR        "Handle creation failed"
#define LDAP_SSL_EXTENDED_ERROR_INITIALIZATION_FAILED          426
#define LDAP_SSL_EXTENDED_ERROR_INITIALIZATION_FAILED_STR         "Initialization failed"
#define LDAP_SSL_EXTENDED_ERROR_LDAP_NOT_AVAILABLE             427
#define LDAP_SSL_EXTENDED_ERROR_LDAP_NOT_AVAILABLE_STR            "LDAP not available"
#define LDAP_SSL_EXTENDED_ERROR_NO_PRIVATE_KEY                 428
#define LDAP_SSL_EXTENDED_ERROR_NO_PRIVATE_KEY_STR                "No private key"
#define LDAP_SSL_EXTENDED_ERROR_PKCS11_LIBRARY_NOTLOADED       429
#define LDAP_SSL_EXTENDED_ERROR_PKCS11_LIBRARY_NOTLOADED_STR      "PKCS11 library not loaded"
#define LDAP_SSL_EXTENDED_ERROR_PKCS11_TOKEN_LABELMISMATH      430
#define LDAP_SSL_EXTENDED_ERROR_PKCS11_TOKEN_LABELMISMATH_STR     "PKCS11 token label mismatch"
#define LDAP_SSL_EXTENDED_ERROR_PKCS11_TOKEN_NOTPRESENT        431
#define LDAP_SSL_EXTENDED_ERROR_PKCS11_TOKEN_NOTPRESENT_STR       "PKCS11 token not present"
#define LDAP_SSL_EXTENDED_ERROR_PKCS11_TOKEN_BADPASSWORD       432
#define LDAP_SSL_EXTENDED_ERROR_PKCS11_TOKEN_BADPASSWORD_STR      "PKCS11 token bad password"
#define LDAP_SSL_EXTENDED_ERROR_INVALID_V2_HEADER              433
#define LDAP_SSL_EXTENDED_ERROR_INVALID_V2_HEADER_STR             "Invalid V2 header"

/* The following may be returned by read and write functions */
#define LDAP_SSL_EXTENDED_INVALID_BUFFER_SIZE                  501
#define LDAP_SSL_EXTENDED_INVALID_BUFFER_SIZE_STR                  "Invalid buffer size"
#define LDAP_SSL_EXTENDED_WOULD_BLOCK                          502
#define LDAP_SSL_EXTENDED_WOULD_BLOCK_STR                          "Would block"

#define LDAP_SSL_EXTENDED_ERROR_NOT_SSLV3                      601 /* V3 required */
#define LDAP_SSL_EXTENDED_ERROR_NOT_SSLV3_STR                      "Not SSL V3"
#define LDAP_SSL_EXTENDED_MISC_INVALID_ID                      602
#define LDAP_SSL_EXTENDED_MISC_INVALID_ID_STR                      "Miscellaneous invalid ID"

/* The following may be returned by gsk_attribute_set_ functions */
#define LDAP_SSL_EXTENDED_ATTRIBUTE_INVALID_ID          701
#define LDAP_SSL_EXTENDED_ATTRIBUTE_INVALID_ID_STR            "Invalid attribute"
#define LDAP_SSL_EXTENDED_ATTRIBUTE_INVALID_LENGTH      702
#define LDAP_SSL_EXTENDED_ATTRIBUTE_INVALID_LENGTH_STR        "Invalid length"
#define LDAP_SSL_EXTENDED_ATTRIBUTE_INVALID_ENUMERATION 703
#define LDAP_SSL_EXTENDED_ATTRIBUTE_INVALID_ENUMERATION_STR   "Invalid enumeration"
#define LDAP_SSL_EXTENDED_ATTRIBUTE_INVALID_SID_CACHE   704
#define LDAP_SSL_EXTENDED_ATTRIBUTE_INVALID_SID_CACHE_STR     "Invalid session ID (SID) cache"
#define LDAP_SSL_EXTENDED_ATTRIBUTE_INVALID_NUMERIC_VALUE 705
#define LDAP_SSL_EXTENDED_ATTRIBUTE_INVALID_NUMERIC_VALUE_STR "Invalid numeric value"
#define LDAP_SSL_EXTENDED_CONFLICTING_VALIDATION_SETTING  706
#define LDAP_SSL_EXTENDED_CONFLICTING_VALIDATION_SETTING_STR  "Invalid setting"

/* The following must be returned by additional certificate validation callback*/
#define LDAP_SSL_EXTENDED_VALIDATION_SUCCESSFUL 0
#define LDAP_SSL_EXTENDED_UNKNOWN_CRIT_EXTNS    575019
#define LDAP_SSL_EXTENDED_NO_CRLS_FOUND         575040

/* The following may be returned by certificate prompt callback routines*/
#define LDAP_SSL_EXTENDED_SC_OK                         1501
#define LDAP_SSL_EXTENDED_SC_CANCEL                     1502

/* The following is return by gskit to pkcs11 callback routine when */
/* the password user entered is incorrect                           */
#define LDAP_SSL_EXTENDED_NOT_FIRST_CALL                "0xFFFFFFFF"
#endif 
/****************************** End of GSKit 6 *****************************************/

#ifdef __OS400__ 
/*
        Return values returned from ldap_ssl_client_init(), ldap_ssl_init()
          and ldap_ssl_start()
*/

#define LDAP_SSL_INITIALIZE_OK               0  /* Successful Completion           */
#define LDAP_SSL_KEYFILE_IO_ERROR            1  /* Warning: keyring io error       */
#define LDAP_SSL_KEYFILE_OPEN_FAILED         2  /* Warning: keyring open error     */
#define LDAP_SSL_KEYFILE_BAD_FORMAT          3  /* Warning: keyring format problem */
#define LDAP_SSL_KEYFILE_BAD_PASSWORD        4  /* Warning: Keyring password bad   */
#define LDAP_SSL_KEYFILE_BAD_MALLOC          5  /* Error: Malloc failed            */
#define LDAP_SSL_KEYFILE_NOTHING_TO_WRITE    6
#define LDAP_SSL_KEYFILE_WRITE_FAILED        7
#define LDAP_SSL_KEYFILE_NOT_FOUND           8
#define LDAP_SSL_KEYFILE_BAD_DNAME           9  /* Error: Invalid distinguish name */
#define LDAP_SSL_KEYFILE_BAD_KEY            10
#define LDAP_SSL_KEYFILE_KEY_EXISTS         11
#define LDAP_SSL_KEYFILE_BAD_LABEL          12
#define LDAP_SSL_KEYFILE_DUPLICATE_NAME     13
#define LDAP_SSL_KEYFILE_DUPLICATE_KEY      14
#define LDAP_SSL_KEYFILE_DUPLICATE_LABEL    15
#define LDAP_SSL_BAD_FORMAT_OR_INVALID_PW            16
#define LDAP_SSL_ERR_INIT_PARM_NOT_VALID   100  /* Error: invalid cipher spec      */
#define LDAP_SSL_INIT_HARD_RT              101  /* Warning: no keyring file or pw  */
#define LDAP_SSL_INIT_SEC_TYPE_NOT_VALID   102  /* Error: invalid security type    */
#define LDAP_SSL_INIT_V2_TIMEOUT_NOT_VALID   103  /* Error: invalid V2 timeout value */
#define LDAP_SSL_INIT_V3_TIMEOUT_NOT_VALID   104  /* Error: invalid V3 timeout value */
#define LDAP_SSL_KEYFILE_CERT_EXPIRED      105  /* Error: Certificate has expired */

#define LDAP_SSL_KEYRING_NOT_FOUND  106       /* Error: SSL Keyring file not found */
#define LDAP_SSL_PASSWORD_NOT_SPECIFIED 107 /* Error: SSL pasword not specified */

#ifndef __skit_h

#define SKIT_INITIALIZE_OK             0 /* Successful Completion           */
#define SKIT_KEYFILE_IO_ERROR          1 /* Warning: keyring io error       */
#define SKIT_KEYFILE_OPEN_FAILED       2 /* Warning: keyring open error     */
#define SKIT_KEYFILE_BAD_FORMAT        3 /* Warning: keyring format problem */
#define SKIT_KEYFILE_BAD_PASSWORD      4 /* Warning: Keyring password bad   */
#define SKIT_KEYFILE_BAD_MALLOC        5 /* Error: Malloc failed            */
#define SKIT_KEYFILE_NOTHING_TO_WRITE  6
#define SKIT_KEYFILE_WRITE_FAILED      7
#define SKIT_KEYFILE_NOT_FOUND         8
#define SKIT_KEYFILE_BAD_DNAME         9 /* Error: Invalid distinquish name */
#define SKIT_KEYFILE_BAD_KEY          10
#define SKIT_KEYFILE_KEY_EXISTS       11
#define SKIT_KEYFILE_BAD_LABEL        12
#define SKIT_KEYFILE_DUPLICATE_NAME   13
#define SKIT_KEYFILE_DUPLICATE_KEY    14
#define SKIT_KEYFILE_DUPLICATE_LABEL  15
#define SKIT_ERR_INIT_PARM_NOT_VALID 100 /* Error: invalid cipher spec      */
#define SKIT_INIT_HARD_RT            101 /* Warning: no keyring file or pw  */
#define SKIT_INIT_SEC_TYPE_NOT_VALID 102 /* Error: invalid security type    */
#define SKIT_INIT_V2_TIMEOUT_NOT_VALID 103 /* Error: invalid V2 timeout value */
#define SKIT_INIT_V3_TIMEOUT_NOT_VALID 104 /* Error: invalid V3 timeout value */
#define SKIT_KEYFILE_CERT_EXPIRED    105 /* Error: Certificate has expired */

/*
        Return codes. These are returned as an LDAP_OPT_EXT_ERROR, using
        ldap_get_option(), when an SSL-related error has occurred.
 
        Use ldap_get_option() with LDAP_OPT_EXT_ERROR to get a more detailed SSL
        error code whenever LDAP_SSL_HANDSHAKE_FAILED is returned from an LDAP call
        to use the new #defines listed above.
*/


#define SKIT_SOC_BAD_V2_CIPHER                   -40
#define SKIT_SOC_BAD_V3_CIPHER                   -41
#define SKIT_SOC_BAD_SEC_TYPE                    -42
#define SKIT_SOC_BAD_SEC_TYPE_COMBINATION        -102
#define SKIT_SOC_NO_READ_FUNCTION                -43
#define SKIT_SOC_NO_WRITE_FUNCTION               -44

#define SKIT_ERROR_NO_CIPHERS                    -1
#define SKIT_ERROR_NO_CERTIFICATE                -2
#define SKIT_ERROR_BAD_CERTIFICATE               -4
#define SKIT_ERROR_UNSUPPORTED_CERTIFICATE_TYPE  -6
#define SKIT_ERROR_IO                            -10
#define SKIT_ERROR_BAD_MESSAGE                   -11
#define SKIT_ERROR_BAD_MAC                       -12
#define SKIT_ERROR_UNSUPPORTED                   -13
#define SKIT_ERROR_BAD_CERT_SIG                  -14
#define SKIT_ERROR_BAD_CERT                      -15
#define SKIT_ERROR_BAD_PEER                      -16
#define SKIT_ERROR_PERMISSION_DENIED             -17
#define SKIT_ERROR_SELF_SIGNED                   -18
#define SKIT_ERROR_BAD_MALLOC                    -20
#define SKIT_ERROR_BAD_STATE                     -21 /* V3 */
#define SKIT_ERROR_SOCKET_CLOSED                 -22
#define SKIT_ERROR_SKIT_INITIALIZATION_FAILED    -23
#define SKIT_ERROR_HANDLE_CREATION_FAILED        -24
#define SKIT_ERROR_UNKNOWN_ERROR                 -99

#endif /* __skit_h */
#endif /* __OS400__ */
#endif /* _LDAPSSL_H */

